1 Introduction
In the present series of papers [1,2], we are studying the algebraic
formulation of the general bosonic prototype
of the new orbifold-string theories of permutation-type, emphasizing the target space-times of these theories.
The general prototypes include the string theories [3]
|
|
|
(1.1) |
thus extending our previous work [4-7] which was primarily at .
Here, the permutation group permutes the copies of the critical closed string , while
(the untwisted space-time automorphism group) is any automorphism group which acts uniformly on each copy.
The closed-string (generalized permutation) orbifolds involve left- and right-mover copies of the
algebras of the open-string counterparts .
Our description also includes
the orientation-orbifold string systems [3-6]:
|
|
|
(1.2) |
In these cases permutes the left-and right-movers of the
critical closed string, and these string systems contain an equal number of twisted open- and closed-string sectors. The
open-string sectors of the orientation-orbifolds are included
in , while the closed-string sectors
form the space-time orbifold .
We remind that these theories have many sectors
corresponding to the equivalence classes of the divisors , so
that each corresponds to a choice of element in the permutation group or as well as the space-time automorphism group .
With the help of BRST quantization [4,1], the conformal cycle-dynamics of the general bosonic prototype
has been determined [2] up to the choice of the automorphism subgroup
and, so that the paper is essentially self-contained, we begin here with
a brief review of this dynamics.
In particular, we know the extended physical-state conditions and orbifold Virasoro generators
for each cycle of each sector of the open-string prototype in Eq. (1.1)
|
|
|
|
|
|
|
|
|
|
where in Eqs. (1.3a,c) is the intercept of cycle
in sector . The associated mode algebras are as follows
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
(1.4j) |
|
|
|
(1.4k) |
where Eq. (1.4a) is a set of orbifold Virasoro algebras [8,16,1,2].
The results in Eqs. (1.3) and (1.4) are the description of the theories at cycle central charge , where is the length of cycle in
each element of or . The
sector central charges of each string theory are obtained by summing over
the cycles with the sum rule in Eq. (1.4f). The reader is reminded that the
(closed-string) generalized permutation orbifolds in Eq. (1.1) additionally require a corresponding set of right-mover operators.
We will return below to specify the normal-ordering of the orbifold
Virasoro generators, the precise forms of the conformal
weights and in particular the quantities
–
which together encode the specific element of the space-time
symmetry group .
We also know a map [2] from the description of the extended physical-state condition
(1.3) of each cycle to an equivalent,reduced formulation of
the physical states of cycle at reduced cycle central
charge . The explicit form of the map between the operators of the two
formulations is
|
|
|
|
(1.5a) |
|
|
|
(1.5b) |
|
|
|
(1.5c) |
where covers the integers once
. Then the reduced (unhatted) operators provide the following
equivalent, reduced description of cycle in sector :
|
|
|
|
(1.6a) |
|
|
|
The precise form of the conformal-weight shifts
in Eq. (1.6b) will also be reviewed below. The mode algebras of the reduced formulation are as follows
|
|
|
|
(1.7a) |
|
|
|
|
|
|
|
|
|
(1.7g) |
We see in particular that the reduced Virasoro generators satisfy the ordinary
Virasoro algebras (1.7a) at reduced cycle central charges
, and we note as well that the reduced physical-state
condition (1.6a) of each cycle
exhibits unit intercept, as in ordinary untwisted string theory. It must
be emphasized [5,2] that the physical states
described by the reduced conditions are exactly the same physical states as those
described in Eq. (1.3a), now re-expressed via the map in terms of the
reduced currents.
In the reduced description, one has unwound the part of the twist associated to cycle of the relevant element of ,
leaving unconventionally-twisted currents with fractional modeing . We know that the unreduced
formulation is local [3], so one suspects
that the equivalent, reduced formulation is generically non-local, a question to which we shall return in later papers. An exception to this
intuition of course is the case where, in agreement with the map, the reduced formulation is the same as the unreduced.
We turn now to the precise forms [2] of various structures in the formulations above. In both the original and reduced
formulations, the orbifold Virasoro generators (1.3b) and the reduced
Virasoro generators (1.6b) are defined as mode-normal-ordered forms:
|
|
|
(1.8) |
The conformal weights and conformal weight-shifts of cycle in sector have
been computed as follows:
|
|
|
|
(1.9a) |
|
|
|
(1.9b) |
|
|
|
(1.9c) |
Other properties of the function are given in Ref. [2].
Finally, the choice of element is encoded in the new string theories by first solving
the eigenvalue problem [10,12] of
|
|
|
|
(1.10a) |
|
|
|
|
|
|
(1.10d) |
|
|
|
(1.10e) |
where is the untwisted target-space metric of and
are called respectively the spectral and degeneracy indices of the element. The quantity
is the order of , and is the pullback to the fundamental region
of the spectral indices. This information appears in the modeing of both
formulations, where we also see the twisted metric
and its inverse :
|
|
|
|
(1.11a) |
|
|
|
(1.11b) |
|
|
|
(1.11c) |
The quantities are a set of essentially arbitrary normalizations.
Our first task in the body of this paper will be to choose a large, explicit set of automorphism groups , so
that the eigenvalue problems and hence the operator systems in either formulation can be fully evaluated.
A central question in the physics of the new string theories is the
target space-time of each cycle in sector ,
which we have discussed in general [2], without choosing any particular non-trivial . In fact,
all salient features of the target space-times are invariant under the choice of unreduced or reduced formulation.
Thus we have seen that [2]
|
|
|
|
(1.12a) |
|
|
|
(1.12b) |
|
|
|
(1.12c) |
|
|
|
(1.12d) |
|
|
|
(1.12e) |
|
|
|
(1.12f) |
where are the zero modes and is the target space-time dimension of
cycle in sector . The general forms of the momentum-squared
operators (1.12b) are given
in Ref. [2], and the quantities and are the ground-state mass-squareds
respectively of the open- and closed- string sectors. Finally, the level-spacings are the
increments of associated
to adding negative-moded currents to the states of cycle .
To illustrate the general results above, we will study in this paper
a large, explicit set of examples of the new orbifold-string theories of permutation-type,
using both the description at cycle central charge and the equivalent, reduced formulation
at reduced cycle central charge . We will focus here on the computation of the target space-time
dimension of each cycle in
every sector of these theories (see Secs. 4 and 5), including the
target space-time signature and the target-space-time
symmetry of each cycle (see Secs. 7, 8 and 10).
In particular, we will use the simplicity of the equivalent, reduced
formulation to see a gratifying target space-time symmetry
enhancement (again see Secs. 7,8 and 10) which naturally matches the full space-time symmetry of each
cycle to the space-time dimensions of the cycle. We will find many simple orbifold-string theories
(for example the orbifolds of -permutation-type) where the space-times are entirely Lorentzian, but
higher sub-examples can be Lorentzian ,
Euclidean and even , with varying sector- and cycle-dependent space-times even in a single orbifold.
2 A Large Set of Examples
In the summary above, the subgroup can be any automorphism group of the critical closed string . Here we begin
our discussion of a large set of examples with the following explicit choice of :
|
|
|
|
(2.1a) |
|
|
|
(2.1b) |
The examples (2.1) then involve two permutation groups, the basic permutation group on copies
of and the spatial permutation group on spatial dimensions of .
The orientation-orbifold string systems can be included with the same by the substitutions
and
. Indeed, examples of all the orbifold-string systems of
-permutation-type [5] have been studied with this choice of .
More precisely, we will study all the sectors associated to the elements of
|
|
|
|
(2.2a) |
|
|
|
(2.2b) |
at each fixed j-cycle length .
In these examples, the parameter partitions the 26 dimensions of each
critical closed string into a set of and dimensions.
Referring to the eigenvalue problem (1.10), we see that the action on the set of dimensions is very simple:
|
|
|
|
(2.3a) |
|
|
|
(2.3b) |
|
|
|
(2.3c) |
Here we have chosen trivial eigenmatrices and , as well as trivial
normalizations . The quantity
|
|
|
(2.4) |
is the restriction of the 26-dimensional metric to the first dimensions.
The action of on the remaining set of spatial
dimensions is any element of any permutation group on elements.
The results for general permutation groups [14,16,3-5] are well known in the orbifold
program and we find in these cases:
|
|
|
|
(2.5a) |
|
|
|
(2.5b) |
|
|
|
(2.5c) |
|
|
|
(2.5d) |
Here is the length of cycle in the element of , and
the reader may profit by comparing the ranges (2.5d) for the indices
associated to the elements of with
the ranges (1.4f) for the indices associated with the elements of the
basic permutation group .
The notation for our large example here is very similar to that chosen in Ref. [5], except that we
are using capital letters here for the elements of , in order to distinguish it from the
small letters we are now using to describe the elements of .
Let us note with Eq. (2.2b) that we cannot choose in the partition – because is
not an automorphism group of the untwisted Lorentzian critical closed string .
Using in particular the twisted metrics (2.3d) and (2.5b,c) , we may then write down the explicit form
in our large example of the general results summarized in Sec.1.
We begin with the orbifold Virasoro generators at ,
which now take the following explicit form:
|
|
|
|
|
|
|
(2.6e) |
Note that the orbifold Virasoro generators are additive with respect to the contributions
of and . In what follows, we shall refer to these
contributions respectively as those of type (d) and of type (26-d).
Similarly, we find
the following explicit forms of the conformal weights and conformal-weight shifts:
|
|
|
|
(2.7a) |
|
|
|
(2.7b) |
|
|
|
(2.7c) |
|
|
|
Here the conformal-weight shifts are given as the sum of the
contributions of type (d) and type (26-d), and we have used slightly rearranged arguments of the Heaviside functions .
The corresponding twisted mode algebras include Eq. (1.4a) for the orbifold Virasoro generators and the following algebras
involving the two types of twisted currents
|
|
|
|
|
|
|
|
|
|
(2.8e) |
|
|
|
|
|
|
To these algebras we may append the periodicity relations (1.4d) of the
orbifold Virasoro generators and the two types of currents:
|
|
|
|
(2.9a) |
|
|
|
(2.9b) |
|
|
|
Finally we add the adjoint operations of the large example
|
|
|
|
(2.10a) |
|
|
|
(2.10b) |
|
|
|
(2.10c) |
which follow easily from the general orbifold adjoint operation of Ref. [12]. Special cases of these adjoint operations
were given for the "pure" permutation orbifolds (trivial ) in Refs. [16,2].
With the adjoint operations and the current-current commutators in Eqs. (2.8b,e), we can compute the norm of any basis state
in cycle of sector , for example:
|
|
|
|
|
|
|
|
|
|
Here is the momentum-boosted
twist-field state [2] of cycle in sector ,
which is annihilated by all positively-moded currents. The relation of
this state to the physical ground-state of the cycle is discussed in
Secs. 7-9. Similarly, it is straightforward to compute the norms
of any number of negatively-moded currents on this state and we conclude that the only basis states with negative norm
are associated, as in ordinary string theory, with an odd number of time-like currents (i.e. because ).
In particular, no negative norms are associated with the twisted currents of the second type.
To conclude the formulation of the large example at , we remind the reader of
the ground-state momentum-squared in Eq. (1.12), and give the explicit
form of the increments (level-spacing) of the momentum-squared
|
|
|
|
(2.12a) |
|
|
|
(2.12b) |
|
|
|
(2.12c) |
which are obtained on addition of a negatively-moded current of either type to a
physical state. We shall return later to the fact
that all the increments are strictly positive. The explicit form of the
generalized number operator
is easily
obtained from Eqs. (2.6a),(2.10) and (2.12b).
Next, we give the explicit form of the large example in the equivalent reduced
formulation at reduced cycle central charge .
We begin with the explicit form of the reduced Virasoro generators
|
|
|
(2.13) |
where the conformal weight-shifts of the large example are given in Eqs. (2.7b-d). The reduced mode algebras consist
of the ordinary Virasoro algebras (1.7a) at and the algebras
involving the reduced current modes of both types:
|
|
|
|
(2.14a) |
|
|
|
|
|
|
|
|
|
Similarly, the reduced periodicities and adjoint operations are obtained
as follows
|
|
|
|
(2.15a) |
|
|
|
(2.15b) |
|
|
|
(2.15c) |
|
|
|
(2.15d) |
|
|
|
(2.15e) |
Then the reduced current-current commutators and adjoint operations directly
give the following reduced analogues of the norm computations:
|
|
|
|
(2.16a) |
|
|
|
(2.16b) |
|
|
|
|
|
|
With , the reduced norms are seen to be the same as the
unreduced norms in Eq. (2.11). Indeed, since the map (1.5) is only an operator-relabeling,
all inner products are the same in the two formulations.
In particular we see again with Eqs. (2.14b) and (2.15d) that the only negative-norm basis states are those with an odd number of negatively-moded time-like currents
, in parallel to ordinary string theory.
Finally, the increments of the reduced momentum-squared are obtained
|
|
|
|
(2.17a) |
|
|
|
(2.17b) |
|
|
|
(2.17c) |
from the reduced physical-state conditions (1.6a) when a negatively-moded reduced current of either type is added to the state.
Using , it is easily seen that these increments are the
same as the unreduced increments in Eq. (2.12c). The explicit form of the
reduced number operator
can be
obtained from Eqs. (2.13),(2.15) and (2.17b).
4 The Zero Modes of Type ()
The zero modes of type are easily located in the reduced currents of type
|
|
|
where we remind that the parameter corresponds respectively to
the d-dimensional automorphisms and .
The results are
|
|
|
|
(4.1a) |
|
|
|
(4.1b) |
|
|
|
(4.1c) |
The total number of zero modes of type in cycle of sector
is then summarized as follows:
|
|
|
|
(4.2a) |
|
|
|
(4.2b) |
The corresponding contribution of the zero modes of type to the momentum-squared operator of cycle in sector
|
|
|
|
(4.3a) |
|
|
|
also follows from the general results of Ref. [2]. The currents with
are defined by the periodicity relation (2.9b).
Including then the adjoint operation in Eq. (2.15d), we may further verify that
|
|
|
|
(4.4a) |
|
|
|
(4.4b) |
where the form (4.4b) of the momentum-squared holds on any state with diagonalized momenta.
To these observations, we add a closely-related result. It is not difficult
to do the sum in Eq. (2.7c), obtaining the following explicit form
for the contribution of the currents of type to the conformal-weight shifts:
|
|
|
|
(4.5a) |
|
|
|
(4.5b) |
In completing these sums, one notices for the first two cases of
Eq. (4.5b) that no terms at all are allowed by the Heaviside functions of
Eq. (2.7c). Similarly for the last case of (4.5b), only
the term with contributes.
It is instructive then to consider the results (4.5) together with the previous
result (4.2) for the number of space-time dimensions of type . In particular consider the cases
or and even, for which there are zero modes and no conformal-weight shifts of type . We can see
both of these results explicitly
in the contributions of type to the reduced Virasoro generators (2.13), which can be put in the form
|
|
|
by shifting the integer in the sum. In these cases, we see only integer-moded sequences which (as in the ordinary untwisted string)
can never [2] produce conformal-weight shifts. In the other case ( and odd), we see only fractional-moded sequences
(no zero modes) and non-zero conformal-weight shifts.
5 The Zero Modes of Type ()
We consider next the zero modes of the currents of type (26-d),
associated to each element :
|
|
|
|
(5.1a) |
|
|
|
(5.1b) |
|
|
|
(5.1c) |
We remind that is the length of cycle in the chosen
element of , while and are respectively the length of cycle
and the number of -cycles in the chosen element of .
This part of the problem is
trivial () for because the group is trivial, with no room
for any -cycles in . For the rest of this section we therefore restrict the discussion to the
non-trivial range . (We shall return to include
the theories in the later discussion, reminding
the reader here only that the "pure" permutation orbifolds with have already
been discussed in Ref. [2]).
The problem of finding the zero modes of the currents in Eq. (5.1) is equivalent to finding all solutions of the conditions:
|
|
|
(5.2) |
These conditions are a special case of the general description of the zero-mode problems for all in Ref. [2].
On examination of these conditions, we find that the solutions of the
zero-mode problem of type can be conveniently stated at fixed
-cycle length in terms of exactly three
distinct classes of -cycles and their corresponding momenta.
Class I (exceptional). For each cycle with
|
|
|
(5.3) |
we find the (exceptional) zero modes in cycle
|
|
|
|
(5.4a) |
|
|
|
(5.4b) |
In this class, all indices give zero modes, but only those particular values which satisfy the constraints in Eq. (5.2).
Class II (exceptional).
For each -cycle with
|
|
|
(5.5) |
we find the (exceptional) zero modes in cycle
|
|
|
|
(5.6a) |
|
|
|
(5.6b) |
Class III (generic). In the generic -cycle, neither nor is an integer, and we find that the only zero modes are the currents with
|
|
|
(5.7) |
for each generic -cycle.
We note in particular that every -cycle, in any of the three classes, contains at least one zero mode.
In the general zero-mode classification of Ref. [2], the generic class
III here provides examples of general type I, while both the exceptional classes I
and III here are examples of general type II.
The three classes of -cycles above can simply be described as follows:
|
|
|
|
|
(5.8a) |
|
|
|
|
(5.8b) |
|
|
|
|
(5.8c) |
Note that -cycles with length are counted in Class II. We illustrate with a few simple examples.
For , we find
|
|
|
|
|
(5.9a) |
|
|
|
|
(5.9b) |
|
|
|
|
(5.9c) |
Similarly for any prime we find
|
|
|
|
|
(5.10a) |
|
|
|
|
(5.10b) |
|
|
|
|
(5.10c) |
and for :
|
|
|
|
|
(5.11a) |
|
|
|
|
(5.11b) |
|
|
|
|
(5.11c) |
Further examples are easily worked out by the reader.
With this classification, we can write down an expression for the
contribution of type to the target space-time dimension of cycle in sector :
|
|
|
|
(5.12a) |
|
|
|
(5.12b) |
|
|
|
(5.12c) |
|
|
|
(5.12d) |
Here the sums are over the -cycles of Class I, II, or III, e.g. and is, as above,
the total number of -cycles in the chosen element . The final lower bound in Eq. (5.12d) follows
because every -cycle has
at least one zero mode, and the equality is realized when all -cycles in are generic.
Let us evaluate the result (5.12) in some simple cases, as a function of -cycle length . We begin with the trivial cycle length:
|
|
|
(5.13) |
In this case, all the
contributions are from Class II, and the result in Eq. (5.13) applies to the trivial element of any with
|
|
|
(5.14) |
as well as many cycles of unit length in the elements of .
We consider next some examples of -cycle length as they occur in some full orbifold-string theories, for example
|
|
|
(5.15) |
Having already discussed the trivial element of , we focus now only on the non-trivial elements of . I
begin with , for which all non-trivial elements of have a single cycle . For each of these sectors we find:
|
|
|
(5.16) |
Note in particular that for the single non-trivial element of the simplest case , this can be simplified to
|
|
|
(5.17) |
where are respectively the number of -cycles of even and odd length in . This
result is in agreement with the counting of zero modes in Ref. [5].
For , we have 2 non-trivial single -cycle elements with
|
|
|
(5.18) |
and one sector with 2 -cycles of length 2, each of which is described by Eq. (5.17)
For , we have one non-trivial sector with a single -cycle of length and hence
|
|
|
(5.19) |
where are respectively the number of -cycles of length 1, 2, 4, and multiples of 8.
The other non-trivial elements of include 5 two-cycle elements (), each of which has (use Eq. (5.18))
and one element with 4 -cycles of length (use Eq. (5.17)). In this way, the non-trivial sectors of are easily worked out
by induction from the results of , adding at each step only the single -cycle result for =.
We may also write down the corresponding contribution of type to the
momentum-squared operator [2] of cycle in sector :
|
|
|
|
(5.20a) |
|
|
|
|
|
|
(5.20e) |
Here I have chosen for simplicity to rescale each of the zero modes according to Eq.(5.20e).
Finally, the adjoint operations in Eq. (2.15) imply
|
|
|
|
(5.21a) |
|
|
|
where the form (5.21b) of the momentum-squared holds on any state with diagonalized momenta.
As anticipated above, the contribution of type to the momentum-squared operator is indeed space-like.
7 Lorentzian Space-Time Symmetry
Following the previous discussion, this section is limited to the discussion of the following two cases
|
|
|
(7.1) |
for which we shall see that the dynamics of cycle is Lorentzian. We remind the reader
that the values correspond respectively to and .
In these two cases, our large example can be put into the following form:
|
|
|
|
|
|
|
Here is the target space-time dimension of cycle in sector , is the
corresponding -dimensional flat Minkowski-space metric,
and the conformal-weight shifts of type are given in Eq. (2.7d). The generators are
Virasoro with uniform cycle central charge
|
|
|
(7.3) |
and the two kinds of currents satisfy the algebra:
|
|
|
|
(7.4a) |
|
|
|
(7.4b) |
|
|
|
(7.4c) |
|
|
|
The -dimensional Minkowski metric is seen again in Eq. (7.4c).
In this system, we have collected all the integer-moded sequences ( of type plus of type )
and used the rescaling/relabeling (6.3) to write all the integer-moded sequences in a unified notation as
ordinary untwisted string coordinates. See in particular
the ordinary untwisted current algebra of all the
integer-moded sequences in Eq. (7.4c) and the first term of the Virasoro generators (7.2a), which can be put in
this “ordinary form” after a shift under the sum on . ( The shift, by the integer even, is
only necessary for .) We remind the reader
that this “ordinary” term does not contribute to the conformal-weight shift in the third term
of the Virasoro generators – which comes entirely from the
fractional-moded sequences. Similarly, the ground-state mass-squared (1.12c)
of cycle in sector
|
|
|
(7.5) |
is shifted only by the fractionally-moded sequences.
The prime on the sum in the second term of the Virasoro generators (7.2a) denotes omission of the integer-moded sequences
of type , which we understand are now included in the first
(ordinary) term. The second term therefore sums only over the
fractional-moded sequences of type , whose twisted
current algebra is given in Eq. (7.4d).
Since the integer-moded sequences commute with the fractional-moded sequences, we
see that the first (ordinary) term of the Virasoro generators,
as well as the combination of the second and third terms of the generators, form two commuting sets of Virasoro
generators – with central charges and respectively.
It is clear that the first term in Eq. (7.2a) is a set of ordinary untwisted Virasoro generators on a Lorentzian target space of
dimension . Therefore the dynamics of cycle in sector has an Lorentz symmetry, under which
the integer-moded currents transform as Lorentz-vectors of dimension , while
the fractional-moded currents transform as scalars under the
Lorentz group. This conclusion is one of the central results of this paper.
Of course, in these cases the integer-moded sequences of type
already possessed a “primordial” Lorentz symmetry so that the
true target space-time symmetry of cycle in sector
can be understood as an enhanced Lorentz symmetry. This enhanced
Lorentz symmetry is transparent in the system only after
we have collected (and rescaled) the integer-moded sequences both of type
and type . We emphasize that the enhanced
symmetry is a completely natural one, given
the total number of target space-time dimensions. See Ref. [2] for an
outline of the target
space-time dimensions in more general orbifold-string
theories of permutation-type.
Here we have discussed the enhanced Lorentz symmetry of cycle only in the equivalent, reduced formulation of the cycle
at . Using the inverse of the map (1.5), it is also possible to see this symmetry in the original formulation
of the cycle at – a subject to which we will return elsewhere.
With their ordinary -dimensional string subspaces and extra
twisted scalar currents, these Lorentzian systems may appear at first sight to
resemble some ordinary target-space string compactification which leaves only continuous dimensions. But in fact
the sector structure and characteristic modeing
of the extra scalar currents shows
clearly that these systems are quite distinct from compactification, and
generically new for all and .
This conclusion generalizes our earlier statement [5] for the simple
cases or .
I close this section with a few remarks about negative-norm states in
these Lorentzian string systems.
For the Lorentzian cycles, the adjoint operations include the generalized
hermiticity (2.15c) of the reduced Virasoro generators as well as
|
|
|
|
(7.6a) |
|
|
|
(7.6b) |
and the periodicity condition (2.15b) continues to hold for the fractional sequences. Then, following our
discussion in Sec. 2, we see that the negative-norm basis states occur only when the basis state
contains an odd number of "ordinary" time-like modes . If , which we have
not established here beyond the "pure" permutation orbifolds [2] with , then one may continue
to expect [3] that all negative-norm physical states will decouple. We shall continue this discussion in the following
paper, showing in fact that for the all the open-and
closed-string sectors in the large example of
the orientation-orbifold string systems [5] – i.e. and all .
8 Euclidean Space-Time Symmetry
Beyond the Lorentzian cases in Eq. (7.1), there remains to study the
cycles of sector in the case
|
|
|
(8.1) |
which, as we shall see, leads to more exotic strings.
In this case we find the following algebraic systems,
beginning with the reduced Virasoro generators at cycle central charge :
|
|
|
|
|
|
|
(8.2e) |
We remind that the contributions of type to the conformal-weight
shifts and the target-space dimensionalities are given respectively in
Eqs. (2.7d) and (5.12).
The non-zero commutators of these modes are as follows:
|
|
|
|
(8.3a) |
|
|
|
(8.3b) |
|
|
|
(8.3c) |
|
|
|
(8.3d) |
|
|
|
(8.3e) |
|
|
|
(8.3f) |
|
|
|
(8.3g) |
|
|
|
We supplement the mode algebra with the adjoint operations
|
|
|
|
(8.4a) |
|
|
|
(8.4b) |
|
|
|
(8.4c) |
which follow, along with the generalized hermiticity (2.15c) of the
Virasoro generators, from the adjoint operations in Eqs. (2.15d,e). Similarly, the periodicity conditions for these modes are easily worked out from
the corresponding relations in Eqs. (2.15a,b).
These orbifold-string systems are quite different from those of the
previous section, first because they do not have an ordinary Lorentzian
string subsector.
In further detail, these cycles have , i.e. there are no
integer-moded sequences of type . Therefore all integer-moded sequences
are of type , and these target space-times are Euclidean with Euclidean space-time dimension .
After the relabeling (6.3), the integer-moded sequences
of type are collected in the first term of the Virasoro
generators (8.2a), and their Euclidean current algebra is given in
Eq. (8.3f). The Euclidean space-time metric
(Kronecker delta) is seen in both places. The half-integer-moded
currents appear in the second term of Eq. (8.2a) as the entire
contribution of type . Again, the prime on the sum in the third term of Eq. (8.2) denotes the omission
of the integer-moded sequences of type , which we understand are now included in the first term of the Virasoro generators.
These Euclidean cycles have a Euclidean target space-time symmetry , under
which the integer-moded sequences transform as -dimensional
vectors. All remaining modes, including both the half-integer moded sequences and
the fractional-moded sequences , are scalars under this orthogonal group.
The Virasoro generators (8.2) are in fact a sum of three sets of commuting Virasoro generators. The first (Euclidean) term
of Eq. (8.2a) is by itself Virasoro with central charge
|
|
|
(8.5) |
The second (half-integer moded) term of Eq. (8.2a) together with the contribution to the
conformal-weight shift form a second set of Virasoro generators with central charge
|
|
|
(8.6) |
Finally, a third set of Virasoro generators with
|
|
|
(8.7) |
is formed from the third term of Eq. (8.2a) and the contribution to the conformal-weight shift. It
is easily checked then that
|
|
|
(8.8) |
as required for the reduced description of cycle in sector .
The -dimensional Lorentz metric appears in the second term of the Virasoro generators and again in the current algebra (8.3g). This
means that basis states formed with an odd number of time-like scalar operators have negative norm.
As a consequence, in distinction to the Lorentzian cycles, we cannot
expect all Euclidean cycles to be free of negative-norm physical states.
We will give an example of this circumstance below.
This brings us to another salient feature of these Euclidean cycles, namely that
they consist of at most a finite number of physical states, and
these states are mostly tachyonic because the Euclidean momenta satisfy .
To see this, we begin with the zeroth component of the physical-state condition (1.6a) in the schematic form
|
|
|
|
(8.9a) |
|
|
|
(8.9b) |
Here we are assuming that the physical state is diagonal in the momenta
and the generalized number
operator , so that we may treat these quantities as numbers.
The lower bound given for the momentum-squared is the lower bound on the
ground-state momentum-squared in Eq. (1.12c), while the upper bound is
the Euclidean character of the momenta.
That these cycles have at most a finite number of physical states is then
clear from the strict positivity of the increments (level-spacing) in Eq. (2.17).
This can equivalently be seen from the following closely-related double
inequality on the number operator
|
|
|
(8.10) |
and the fact that the increments in Eq. (2.17c) are strictly positive. The Lorentzian
cycles of the previous section have no such upper bound on the momenta or
the number operator, both of which follow
immediately from the Euclidean character of the momenta.
According to Eq. (8.10), there will be in fact no physical states at all in a given Euclidean cycle unless the conformal-weight shifts
and parameter satisfy
|
|
|
|
(8.11a) |
|
|
|
(8.11b) |
|
|
|
(8.11c) |
where Eqs. (8.11b,c) follow from Eq. (8.11a).
The upper bound in Eq. (8.11a) is non-trivial, and we remind that the explicit form of is
given in Eq. (2.7d).
We should also emphasize what is implicit in the discussion above, namely that these
conditions are sufficient to
guarantee the existence of an oscillator-free tachyonic
physical ground state with ground-state momentum-squared:
|
|
|
|
(8.12a) |
|
|
|
(8.12b) |
The first parts of this statement are in accord with
Eqs. (1.12c),(2.7b) and (4.5b),
while the Euclidean upper bound is equivalent to the upper bound in Eq. (8.11a).
In summary, the Euclidean cycles with
|
|
|
(8.13) |
consist of at most a short collection of tachyonic states with the
highest possible states being some number of zero-mass particles.
It is clear that many non-trivial short Euclidean cycles of this type exist
but, as noted above, they may not all be free of negative-norm physical states.
For example choosing and the unit
element of with all ,
we find that and the
tachyonic ground state is found at . The rest of
this short collection consists of
a single excited tachyonic physical state with
negative norm.
The particular example above can be eliminated by judicious choice of divisors for the full
orbifold, but non-trivial short Euclidean cycles deserve further
study elsewhere – not least because
they apparently represent a crossover point between string theory and particle theory.
A related question of interest is the fate of such cycles in the
as-yet-unconstructed orbifold-superstring theories of permutation-type [3], where one may
suspect that the short collections consist only of zero-mass particles.
We finally note that an even more limited spectrum is
possible for certain Euclidean cycles: The conditions in Eqs. (8.11b,c) tell us immediately that
there are no physical states at all for any Euclidean cycle with
|
|
|
(8.14) |
In these cases, we refer to the Euclidean cycle as an extinguished
cycle, and many examples of such cycles are easily constructed from the
conditions (8.14). The following section discusses a simple class of these
extinguished cycles in some detail.
9 Null Cycles
Among the extinguished Euclidean cycles (with no physical states) in
Eq. (8.14), we focus here on a simple set of subexamples
with no momenta at all
|
|
|
(9.1) |
which we call null cycles. Such null cycles are rare among the
extinguished Euclidean cycles, but all the null
cycles in our large example are easily
located with the zero-mode counting above:
|
|
|
(9.2) |
In particular, we have used the fact that every -cycle has at least
one zero mode (see Sec. 5) to obtain the
requirement that for null cycles must be trivial and hence .
It is instructive to consider the fate of some full orbifolds which contain at least some of these extinguished null cycles, for
example the generalized permutation orbifolds
|
|
|
(9.3) |
where we have chosen for odd and displayed all the elements of the divisor . In these examples, all the cycles of all
the sectors after the semi-colon are null extinguished cycles, with no
momenta and no physical particles. This follows because all the elements
of the odd cyclic groups
have cycle lengths odd, including the trivial element with . In this latter case, the
sector arises from the action of on all 26 dimensions of the original closed string , and
the only currents are half-integral moded scalar fields
– a
familiar case [23] with no zero modes.
Thus, as string systems, the set of generalized cyclic
permutation-orbifolds (9.3) degenerate to the "pure" cyclic
permutation-orbifolds
|
|
|
(9.4) |
each cycle of which is in fact known [7,2] to be equivalent to an ordinary 26-dimensional closed string.
I mention in conclusion the intuitive parallel of null cycles to spurions at .
10 Conclusions and Directions
In both the unreduced and the equivalent, reduced formulations we have provided the physical-state conditions and Virasoro
generators of the following large examples of bosonic orbifold-string
systems of permutation type [3,2]:
|
|
|
|
(10.1a) |
|
|
|
(10.1b) |
Here the divisor can be any subgroup of the elements shown, and the complete orbifold-string
system has a sector for each equivalence class of . The theories
are open-string analogues [22,3] of the closed-string systems
, the latter requiring
the addition of right-mover copies of the mode systems given above. Our
analysis also includes the orientation-orbifold string
systems with and ,
on which we comment separately below.
The present paper is an extension of our prior construction [5] at , now
emphasizing the target space-times and target space-time symmetries of the theories (10.1) for all . In the discussion above, the elements
of both permutation groups and are analyzed
in terms of their respective cycle lengths
|
|
|
(10.2) |
and we remind that the elements and
correspond respectively to and in our classification.
As specific subexamples, we may emphasize the generalized orbifold-string systems of cyclic permutation-type:
|
|
|
(10.3) |
In these cases, the -cycles of the non-trivial elements of have all possible lengths which divide K
|
|
|
(10.4) |
where is the order of , and correspondingly, the trivial element of has , .
For all possible choices of the divisor (10.3), our discussion above then provides the following schemata
where or denote -cycles with respectively Lorentzian
or Euclidean target space-times. The dimensionalities of these
space-times are as follows
|
|
|
(10.5) |
and general formulae for the contributions of type are given in Sec. 5.
In fact
the results for and the target space-time dimensionalities in Eq. (10.5) apply more generally
to all -cycles in any sector of the large example (10.1) of orbifold-string
systems of permutation-type, with target space-time symmetry for Lorentzian cycles
and target space-time symmetry for Euclidean cycles.
The Lorentzian cycles appear so far to be new physical generalizations of ordinary string
theory, with -dimensional ordinary Lorentzian string
subsectors and extra characteristically-twisted scalar
fields. The Euclidean cycles are more exotic, being comprised at most of short collections
of particles with – some possibly with negative-norm physical states. On the
other hand, many of the Euclidean cycles are extinguished, with no physical
particles at all,
and there is even a subset of extinguished cycles which we have called
null (no target space-time dimensions and no physical particles).
Although obtained explicitly as enhanced target space-time symmetries in Secs. 7 and 8,
we emphasize that these Lorentzian and Euclidean symmetries are completely natural for the (similarly-enhanced) target space-time
dimensionalities in Eq. (10.5). One therefore expects these same natural space-time
symmetries for all the target space-times [2] of the general
orbifold-string theories in Eq. (1.1). One also expects the
as-yet-unconstructed twist-fields (intertwiners) of these orbifolds to
describe transitions among the various target space-time dimensionalities,
signatures and symmetries of each theory.
We focus finally on orbifold-string systems in our large example whose
target space-times are entirely Lorentzian, for all cycles in all
sectors of the orbifold. Starting with the cyclic examples in
Eq. (10.3) and the Table above, one simple subset of entirely Lorentzian theories has the divisors
|
|
|
(10.6) |
where we have kept only the subgroup of with . Indeed, we have seen in Sec. 7 that all the
generalized orbifold-string systems with
|
|
|
(10.7) |
consist entirely of Lorentzian cycles.
Again consulting the Table above, we can find many other entirely Lorentzian orbifold-string systems in
the cyclic subexamples (10.3). This includes the following simple cases [5,7] with :
|
|
|
|
(10.8a) |
|
|
|
(10.8b) |
Here and the elements of with
are listed after the semi-colon.
The entirely Lorentzian systems in Eq. (10.8) are closely related to the
orientation-orbifold string systems [19,20,22,3-6]
|
|
|
|
(10.9a) |
|
|
|
(10.9b) |
where are the elements of the world-sheet orientation-reversing called .
We remind that the orientation-orbifold string systems are the natural
generalization of orientifolds, each system containing in fact an equal
number of twisted closed strings and twisted open strings. The twisted
closed- and open-string sectors of these systems are given respectively before
and after the semicolon in Eq. (10.9b), with central charges:
|
|
|
|
(10.10a) |
|
|
|
(10.10b) |
Indeed the ordinary critical bosonic open-closed string system has been identified as the simple case
|
|
|
(10.11) |
even at the interacting level [6].
More precisely, our computational results above hold as well for all the
orientation-orbifold string systems,
so all the sectors of all these systems are Lorentzian. The set of all
closed-string sectors of each of these systems is the ordinary space-time orbifold
|
|
|
(10.12) |
which is described in the formulation of this paper as sets of sectors with . In such cases of course the
unreduced and reduced formulations are the same, with all sectors at central charge 26.
The twisted open-string sectors of any orientation-orbifold system are in fact contained in the
open-string analogues described here at
, and we find from the results (5.17) and (10.5) of the text that the dimension of the Lorentzian space-time of each twisted open-string sector is
|
|
|
(10.13) |
where are respectively the number of odd and even -cycles in the
chosen element of .
Because the Lorentzian cycles described in this paper have a
-dimensional ordinary-string subspace,
the next challenge for the new string theories is to prove the necessary
condition for ghost-decoupling [24]
|
|
|
(10.14) |
in each cycle of all Lorentzian orbifold-string systems of
permutation-type. At this point the upper bound (10.14) is only a
strongly-motivated conjecture [3], which has so far been established only for the pure
permutation orbifolds [2] with trivial . In a
subsequent paper [25], we shall employ in particular the result in Eq. (10.13) to show that the
upper bound (10.14) holds for all the cycles of the large example (10.9)
of orientation-orbifold string systems !